@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-shell.c,v 1.32 2005/07/31 18:32:34 chpe Exp $
+ *  $Id: ephy-embed-shell.c,v 1.32.4.2 2005/10/02 22:02:33 chpe Exp $
  */
 
 #include "config.h"
@@ -86,41 +86,53 @@ ephy_embed_shell_get_type (void)
 	return type;
 }
 
+static void
+ephy_embed_shell_dispose (GObject *object)
+{
+	EphyEmbedShell *shell = EPHY_EMBED_SHELL (object);
+	EphyEmbedShellPrivate *priv = shell->priv;
+
+	if (priv->downloader_view != NULL)
+	{
+		LOG ("Unref downloader");
+		g_object_remove_weak_pointer
+			(G_OBJECT (priv->downloader_view),
+			 (gpointer *) &priv->downloader_view);
+		g_object_unref (priv->downloader_view);
+		priv->downloader_view = NULL;
+	}
+
+	if (priv->favicon_cache != NULL)
+	{
+		LOG ("Unref favicon cache");
+		g_object_unref (priv->favicon_cache);
+		priv->favicon_cache = NULL;
+	}
+
+	if (priv->encodings != NULL)
+	{
+		LOG ("Unref encodings");
+		g_object_unref (priv->encodings);
+		priv->encodings = NULL;
+	}
+
+	G_OBJECT_CLASS (parent_class)->dispose (object);
+}
+
 static void
 ephy_embed_shell_finalize (GObject *object)
 {
 	EphyEmbedShell *shell = EPHY_EMBED_SHELL (object);
 
-	LOG ("Unref history");
 	if (shell->priv->global_history)
 	{
+		LOG ("Unref history");
 		g_object_unref (shell->priv->global_history);
 	}
 
-	LOG ("Unref downloader");
-	if (shell->priv->downloader_view)
-	{
-		g_object_remove_weak_pointer
-			(G_OBJECT(shell->priv->downloader_view),
-			 (gpointer *) &shell->priv->downloader_view);
-		g_object_unref (shell->priv->downloader_view);
-	}
-
-	LOG ("Unref favicon cache");
-	if (shell->priv->favicon_cache)
-	{
-		g_object_unref (G_OBJECT (shell->priv->favicon_cache));
-	}
-
-	LOG ("Unref encodings");
-	if (shell->priv->encodings)
-	{
-		g_object_unref (G_OBJECT (shell->priv->encodings));
-	}
-
-	LOG ("Unref embed single");
 	if (shell->priv->embed_single)
 	{
+		LOG ("Unref embed single");
 		g_object_unref (G_OBJECT (shell->priv->embed_single));
 	}
 
@@ -235,6 +247,7 @@ ephy_embed_shell_class_init (EphyEmbedShellClass *klass)
 
 	parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
 
+	object_class->dispose = ephy_embed_shell_dispose;
 	object_class->finalize = ephy_embed_shell_finalize;
 
 	klass->get_embed_single = impl_get_embed_single;
