@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: FilePicker.cpp,v 1.51.2.1 2005/04/07 11:46:32 chpe Exp $
+ *  $Id: FilePicker.cpp,v 1.52.4.1 2005/09/28 13:29:40 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -431,6 +431,21 @@ NS_IMETHODIMP GFilePicker::Show(PRInt16 *_retval)
 	gtk_window_set_modal (GTK_WINDOW (mDialog), TRUE);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (mDialog), FALSE);
 
+	/* If there's just the "ALL" filter, it's no use showing the filters! */
+	GSList *filters = gtk_file_chooser_list_filters (GTK_FILE_CHOOSER (mDialog));
+	if (g_slist_length (filters) == 1)
+	{
+		GtkFileFilter *filter = GTK_FILE_FILTER (filters->data);
+		const char *name = gtk_file_filter_get_name (filter);
+
+		if (!name || strcmp (name, _("All files")) == 0)
+		{
+			gtk_file_chooser_remove_filter (GTK_FILE_CHOOSER (mDialog),
+							filter);
+		}
+	}
+	g_slist_free (filters);
+
 	gtk_widget_show (GTK_WIDGET (mDialog));
 
 	int response;
