@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node.h,v 1.21 2005/01/16 21:17:54 jframeau Exp $
+ *  $Id: ephy-node.h,v 1.23 2005/07/10 20:57:13 chpe Exp $
  */
 
 #ifndef EPHY_NODE_H
@@ -47,6 +47,7 @@ typedef enum
 #include "ephy-node-db.h"
 
 typedef void (*EphyNodeCallback) (EphyNode *node, ...);
+typedef gboolean (*EphyNodeFilterFunc) (EphyNode *, gpointer);
 
 GType	    ephy_node_get_type		    (void) G_GNUC_CONST;
 
@@ -128,6 +129,12 @@ EphyNode     *ephy_node_get_next_child      (EphyNode *node,
 					     EphyNode *child);
 EphyNode     *ephy_node_get_previous_child  (EphyNode *node,
 					     EphyNode *child);
+void	      ephy_node_set_is_drag_source  (EphyNode *node,
+					     gboolean allow);
+gboolean      ephy_node_get_is_drag_source  (EphyNode *node);
+void	      ephy_node_set_is_drag_dest    (EphyNode *node,
+					     gboolean allow);
+gboolean      ephy_node_get_is_drag_dest    (EphyNode *node);
 
 G_END_DECLS
 
