@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.c,v 1.158 2005/08/21 19:04:24 chpe Exp $
+ *  $Id: ephy-tab.c,v 1.158.2.3 2005/10/02 19:00:12 chpe Exp $
  */
 
 #include "config.h"
@@ -64,6 +64,10 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <string.h>
 
+#ifdef ENABLE_PYTHON
+#include "ephy-python.h"
+#endif
+
 #define EPHY_TAB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TAB, EphyTabPrivate))
 
 #define MAX_HIDDEN_POPUPS 5
@@ -834,6 +838,10 @@ ephy_tab_finalize (GObject *object)
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 
+#ifdef ENABLE_PYTHON
+	ephy_python_schedule_gc ();
+#endif
+
 	LOG ("EphyTab finalized %p", tab);
 }
 
@@ -1795,26 +1803,6 @@ ephy_tab_visibility_cb (EphyEmbed *embed, gboolean visibility,
 	g_object_notify (G_OBJECT (tab), "visibility");
 }
 
-static void
-ephy_tab_destroy_brsr_cb (EphyEmbed *embed, EphyTab *tab)
-{
-	EphyWindow *window;
-	GtkWidget *notebook;
-
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
-	LOG ("ephy_tab_destroy_browser_cb tab %p parent %p",
-	     tab, ((GtkWidget *) tab)->parent);
-
-	window = ephy_tab_get_window (tab);
-	g_return_if_fail (window != NULL);
-
-	/* Do not use ephy_window_remove_tab because it will
-	   check for unsubmitted forms */
-	notebook = ephy_window_get_notebook (window);
-	ephy_notebook_remove_tab (EPHY_NOTEBOOK (notebook), tab);
-}
-
 static gboolean
 open_link_in_new_tab (EphyTab *tab,
 		      const char *link_address)
@@ -2045,9 +2033,6 @@ ephy_tab_init (EphyTab *tab)
 	g_signal_connect_object (embed, "visibility",
 				 G_CALLBACK (ephy_tab_visibility_cb),
 				 tab, 0);
-	g_signal_connect_object (embed, "destroy_browser",
-				 G_CALLBACK (ephy_tab_destroy_brsr_cb),
-				 tab, 0);
 	g_signal_connect_object (embed, "ge_dom_mouse_click",
 				 G_CALLBACK (ephy_tab_dom_mouse_click_cb),
 				 tab, 0);
@@ -2211,6 +2196,44 @@ ephy_tab_set_title (EphyTab *tab,
 	g_object_notify (G_OBJECT (tab), "title");
 }
 
+/**
+ * ephy_tab_get_title_composite:
+ * @tab: an #EphyTab
+ *
+ * Returns the title of the web page loaded in @tab.
+ * 
+ * This differs from #ephy_tab_get_title in that this function
+ * will return a special title while the page is still loading.
+ *
+ * Return value: @tab's web page's title. Will never be %NULL.
+ **/
+const char *
+ephy_tab_get_title_composite (EphyTab *tab)
+{
+	EphyTabPrivate *priv;
+	const char *title = "";
+
+	g_return_val_if_fail (EPHY_IS_TAB (tab), NULL);
+
+	priv = tab->priv;
+
+	if (priv->is_blank)
+	{
+		title = _("Blank page");
+	}
+	else if (priv->is_loading &&
+		 priv->loading_title != NULL)
+	{
+		title = priv->loading_title;
+	}
+	else
+	{
+		title = priv->title;
+	}
+
+	return title != NULL ? title : "";
+}
+
 /**
  * ephy_tab_get_title:
  * @tab: an #EphyTab
@@ -2233,11 +2256,6 @@ ephy_tab_get_title (EphyTab *tab)
 	{
 		title = _("Blank page");
 	}
-	else if (priv->is_loading &&
-		 priv->loading_title != NULL)
-	{
-		title = priv->loading_title;
-	}
 	else
 	{
 		title = priv->title;
